@@ -3,15 +3,15 @@ package Unix::Uptime::FreeBSD;
 use warnings;
 use strict;
 
-our $VERSION='0.3201';
+our $VERSION='0.34';
 $VERSION = eval $VERSION;
 
 sub uptime {
     my $class = shift;
     
-    $ENV{PATH} .= ':/usr/local/sbin:/usr/sbin:/sbin';
+    local $ENV{PATH} .= ':/usr/local/sbin:/usr/sbin:/sbin';
     my $boottime = `sysctl kern.boottime`;
-    my ($boot_seconds,$boot_useconds) = $boottime =~ /\s+sec\s+=\s+(\d+),\s+usec\s+=\s+(\d+)/;
+    my ($boot_seconds,$boot_useconds) = $boottime =~ /\s+sec\s+=\s+(\d+),\s+[un]sec\s+=\s+(\d+)/;
     return time() - $boot_seconds;
 }
 
@@ -22,9 +22,12 @@ sub uptime_hires {
         die "uptime_hires: you need to import Unix::Uptime with ':hires'";
     }
 
-    my $boottime = `/sbin/sysctl kern.boottime`;
-    my ($boot_seconds,$boot_useconds) = $boottime =~ /\s+sec\s+=\s+(\d+),\s+usec\s+=\s+(\d+)/;
+    local $ENV{PATH} .= ':/usr/local/sbin:/usr/sbin:/sbin';
+    my $boottime = `sysctl kern.boottime`;
+    my ($boot_seconds,$boot_useconds) = $boottime =~ /\s+sec\s+=\s+(\d+),\s+[un]sec\s+=\s+(\d+)/;
     my $time = Time::HiRes::gettimeofday();
+    # this isn't strictly correct on dfly. but i don't think it actually
+    # uses a real nsec value, so that's ok.
     my $boot_time = $boot_seconds + ($boot_useconds * (10.0**-6));
     return $time - $boot_time;
 }
@@ -35,6 +38,8 @@ sub load_hires {
     require Time::HiRes;
 }
 
+use base 'Unix::Uptime::BSD::Load';
+
 1;
 
 __END__
